@@ -1,12 +1,13 @@
 # coding=utf-8
 __all__ = [
     'api',
+    'api_ids',
     'api_rids',
     'attachments_api',
-    'authentication',
     'authentication_api',
     'authorization',
     'comments_api',
+    'connect_download',
     'datasource',
     'datasource_api',
     'datasource_logset',
@@ -18,7 +19,6 @@ __all__ = [
     'scout_api',
     'scout_asset_api',
     'scout_assets',
-    'scout_backend',
     'scout_catalog',
     'scout_channelvariables_api',
     'scout_chart_api',
@@ -37,6 +37,8 @@ __all__ = [
     'scout_datasource_connection',
     'scout_datasource_connection_api',
     'scout_datasource_connection_api_influx',
+    'scout_favorites',
+    'scout_favorites_api',
     'scout_integrations_api',
     'scout_internal_search_api',
     'scout_jobs_api',
@@ -53,11 +55,16 @@ __all__ = [
     'scout_video_api',
     'scout_workbookcommon_api',
     'secrets_api',
+    'security_api_workspace',
     'storage_datasource_api',
+    'storage_deletion_api',
     'storage_series_api',
     'storage_writer_api',
+    'themes_api',
     'timeseries_archetype',
     'timeseries_archetype_api',
+    'timeseries_channelmetadata',
+    'timeseries_channelmetadata_api',
     'timeseries_logicalseries',
     'timeseries_logicalseries_api',
     'timeseries_seriescache',
@@ -67,5 +74,5 @@ __all__ = [
 
 __conjure_generator_version__ = "4.9.0"
 
-__version__ = "0.506.1"
+__version__ = "0.586.1"
 
