@@ -5,6 +5,9 @@ from .._impl import (
     api_rids_DataSourceRid as DataSourceRid,
     api_rids_DatasetRid as DatasetRid,
     api_rids_NominalDataSourceRid as NominalDataSourceRid,
+    api_rids_SegmentRid as SegmentRid,
+    api_rids_VideoFileRid as VideoFileRid,
     api_rids_VideoRid as VideoRid,
+    api_rids_WorkspaceRid as WorkspaceRid,
 )
 
