@@ -2,14 +2,10 @@
 from .._impl import (
     attachments_api_Attachment as Attachment,
     attachments_api_AttachmentService as AttachmentService,
+    attachments_api_AttachmentUri as AttachmentUri,
     attachments_api_CreateAttachmentRequest as CreateAttachmentRequest,
     attachments_api_GetAttachmentsRequest as GetAttachmentsRequest,
     attachments_api_GetAttachmentsResponse as GetAttachmentsResponse,
-    attachments_api_Label as Label,
-    attachments_api_Property as Property,
-    attachments_api_PropertyName as PropertyName,
-    attachments_api_PropertyValue as PropertyValue,
-    attachments_api_S3Path as S3Path,
     attachments_api_SearchAttachmentsQuery as SearchAttachmentsQuery,
     attachments_api_SearchAttachmentsQueryVisitor as SearchAttachmentsQueryVisitor,
     attachments_api_UpdateAttachmentRequest as UpdateAttachmentRequest,
