@@ -1,8 +1,11 @@
 # coding=utf-8
 from .._impl import (
+    event_ApiEventOrigin as ApiEventOrigin,
     event_ArchiveEvent as ArchiveEvent,
     event_CreateEvent as CreateEvent,
     event_Event as Event,
+    event_EventOrigin as EventOrigin,
+    event_EventOriginVisitor as EventOriginVisitor,
     event_EventRid as EventRid,
     event_EventService as EventService,
     event_EventType as EventType,
@@ -13,6 +16,8 @@ from .._impl import (
     event_SearchQueryVisitor as SearchQueryVisitor,
     event_SortField as SortField,
     event_SortOptions as SortOptions,
+    event_TemplateEventOrigin as TemplateEventOrigin,
     event_UpdateEvent as UpdateEvent,
+    event_WorkbookEventOrigin as WorkbookEventOrigin,
 )
 
