@@ -4,13 +4,19 @@ from .._impl import (
     scout_compute_resolved_api_AggregateEnumSeriesNode as AggregateEnumSeriesNode,
     scout_compute_resolved_api_AggregateNumericSeriesNode as AggregateNumericSeriesNode,
     scout_compute_resolved_api_ArithmeticSeriesNode as ArithmeticSeriesNode,
+    scout_compute_resolved_api_BandPassConfiguration as BandPassConfiguration,
+    scout_compute_resolved_api_BandStopConfiguration as BandStopConfiguration,
     scout_compute_resolved_api_BinaryArithmeticSeriesNode as BinaryArithmeticSeriesNode,
     scout_compute_resolved_api_BitOperationSeriesNode as BitOperationSeriesNode,
+    scout_compute_resolved_api_Cartesian3dBounds as Cartesian3dBounds,
+    scout_compute_resolved_api_Cartesian3dNode as Cartesian3dNode,
+    scout_compute_resolved_api_Cartesian3dNodeVisitor as Cartesian3dNodeVisitor,
     scout_compute_resolved_api_CartesianBounds as CartesianBounds,
     scout_compute_resolved_api_CartesianNode as CartesianNode,
     scout_compute_resolved_api_CartesianNodeVisitor as CartesianNodeVisitor,
     scout_compute_resolved_api_CumulativeSumSeriesNode as CumulativeSumSeriesNode,
     scout_compute_resolved_api_DerivativeSeriesNode as DerivativeSeriesNode,
+    scout_compute_resolved_api_EnumCountDuplicateSeriesNode as EnumCountDuplicateSeriesNode,
     scout_compute_resolved_api_EnumEqualityRangesNode as EnumEqualityRangesNode,
     scout_compute_resolved_api_EnumFilterRangesNode as EnumFilterRangesNode,
     scout_compute_resolved_api_EnumFilterTransformationSeriesNode as EnumFilterTransformationSeriesNode,
@@ -32,6 +38,7 @@ from .._impl import (
     scout_compute_resolved_api_GeoNodeSummaryStrategyVisitor as GeoNodeSummaryStrategyVisitor,
     scout_compute_resolved_api_GeoNodeTemporalSummary as GeoNodeTemporalSummary,
     scout_compute_resolved_api_GeoNodeVisitor as GeoNodeVisitor,
+    scout_compute_resolved_api_HighPassConfiguration as HighPassConfiguration,
     scout_compute_resolved_api_HistogramNode as HistogramNode,
     scout_compute_resolved_api_HistogramNodeVisitor as HistogramNodeVisitor,
     scout_compute_resolved_api_IntegralSeriesNode as IntegralSeriesNode,
@@ -40,6 +47,12 @@ from .._impl import (
     scout_compute_resolved_api_IntersectRangesNode as IntersectRangesNode,
     scout_compute_resolved_api_LatLongBounds as LatLongBounds,
     scout_compute_resolved_api_LatLongGeoNode as LatLongGeoNode,
+    scout_compute_resolved_api_LogFilterSeriesNode as LogFilterSeriesNode,
+    scout_compute_resolved_api_LogSeriesNode as LogSeriesNode,
+    scout_compute_resolved_api_LogSeriesNodeVisitor as LogSeriesNodeVisitor,
+    scout_compute_resolved_api_LogTimeShiftSeriesNode as LogTimeShiftSeriesNode,
+    scout_compute_resolved_api_LogUnionSeriesNode as LogUnionSeriesNode,
+    scout_compute_resolved_api_LowPassConfiguration as LowPassConfiguration,
     scout_compute_resolved_api_MaxSeriesNode as MaxSeriesNode,
     scout_compute_resolved_api_MeanSeriesNode as MeanSeriesNode,
     scout_compute_resolved_api_MinMaxThresholdRangesNode as MinMaxThresholdRangesNode,
@@ -65,6 +78,7 @@ from .._impl import (
     scout_compute_resolved_api_RangesNodeVisitor as RangesNodeVisitor,
     scout_compute_resolved_api_RangesNumericAggregationNode as RangesNumericAggregationNode,
     scout_compute_resolved_api_RawEnumSeriesNode as RawEnumSeriesNode,
+    scout_compute_resolved_api_RawLogSeriesNode as RawLogSeriesNode,
     scout_compute_resolved_api_RawNumericSeriesNode as RawNumericSeriesNode,
     scout_compute_resolved_api_RawUntypedSeriesNode as RawUntypedSeriesNode,
     scout_compute_resolved_api_ResampleConfiguration as ResampleConfiguration,
@@ -74,15 +88,20 @@ from .._impl import (
     scout_compute_resolved_api_ResolvedNodeVisitor as ResolvedNodeVisitor,
     scout_compute_resolved_api_RollingOperationSeriesNode as RollingOperationSeriesNode,
     scout_compute_resolved_api_ScaleSeriesNode as ScaleSeriesNode,
+    scout_compute_resolved_api_Scatter3dNode as Scatter3dNode,
     scout_compute_resolved_api_ScatterNode as ScatterNode,
     scout_compute_resolved_api_SelectValueNode as SelectValueNode,
     scout_compute_resolved_api_SelectValueNodeVisitor as SelectValueNodeVisitor,
     scout_compute_resolved_api_SeriesCrossoverRangesNode as SeriesCrossoverRangesNode,
     scout_compute_resolved_api_SeriesNode as SeriesNode,
     scout_compute_resolved_api_SeriesNodeVisitor as SeriesNodeVisitor,
+    scout_compute_resolved_api_SignalFilterConfiguration as SignalFilterConfiguration,
+    scout_compute_resolved_api_SignalFilterConfigurationVisitor as SignalFilterConfigurationVisitor,
+    scout_compute_resolved_api_SignalFilterSeriesNode as SignalFilterSeriesNode,
     scout_compute_resolved_api_StabilityDetectionRangesNode as StabilityDetectionRangesNode,
     scout_compute_resolved_api_StaleRangesNode as StaleRangesNode,
     scout_compute_resolved_api_SumSeriesNode as SumSeriesNode,
+    scout_compute_resolved_api_SummarizeCartesian3dNode as SummarizeCartesian3dNode,
     scout_compute_resolved_api_SummarizeCartesianNode as SummarizeCartesianNode,
     scout_compute_resolved_api_SummarizeGeoNode as SummarizeGeoNode,
     scout_compute_resolved_api_SummarizeRangesNode as SummarizeRangesNode,
