@@ -1,5 +1,7 @@
 # coding=utf-8
 from .._impl import (
+    scout_workbookcommon_api_CheckAlertReference as CheckAlertReference,
+    scout_workbookcommon_api_EventReference as EventReference,
     scout_workbookcommon_api_UnifiedWorkbookContent as UnifiedWorkbookContent,
     scout_workbookcommon_api_UnifiedWorkbookContentVisitor as UnifiedWorkbookContentVisitor,
     scout_workbookcommon_api_WorkbookContent as WorkbookContent,
