@@ -1,13 +1,8 @@
 # coding=utf-8
 from .._impl import (
-    secrets_api_ArchivedStatus as ArchivedStatus,
     secrets_api_CreateSecretRequest as CreateSecretRequest,
     secrets_api_GetSecretsRequest as GetSecretsRequest,
     secrets_api_GetSecretsResponse as GetSecretsResponse,
-    secrets_api_Label as Label,
-    secrets_api_Property as Property,
-    secrets_api_PropertyName as PropertyName,
-    secrets_api_PropertyValue as PropertyValue,
     secrets_api_SearchSecretsQuery as SearchSecretsQuery,
     secrets_api_SearchSecretsQueryVisitor as SearchSecretsQueryVisitor,
     secrets_api_SearchSecretsRequest as SearchSecretsRequest,
