@@ -3,6 +3,9 @@ from .._impl import (
     storage_writer_api_DirectNominalChannelWriterService as DirectNominalChannelWriterService,
     storage_writer_api_DoublePoint as DoublePoint,
     storage_writer_api_Field as Field,
+    storage_writer_api_IntPoint as IntPoint,
+    storage_writer_api_LogPoint as LogPoint,
+    storage_writer_api_LogValue as LogValue,
     storage_writer_api_MeasurementName as MeasurementName,
     storage_writer_api_NominalChannelWriterService as NominalChannelWriterService,
     storage_writer_api_Points as Points,
